@@ -175,7 +175,7 @@ fn query_list_circuits(
 
         let offset_value = offset.unwrap_or(0);
         let total = circuits.len();
-        let limit_value = limit.unwrap_or_else(|| total as usize);
+        let limit_value = limit.unwrap_or(total as usize);
 
         let circuits = circuits
             .skip(offset_value)
