@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -401,6 +401,10 @@ impl AuthorizationManagerStateMachine {
                 .or_insert(ManagedAuthorizationState {
                     initiating_state: AuthorizationInitiatingState::Start,
                     accepting_state: AuthorizationAcceptingState::Start,
+                    #[cfg(any(
+                        feature = "trust-authorization",
+                        feature = "challenge-authorization"
+                    ))]
                     received_complete: false,
                     local_authorization: None,
                 });
@@ -561,6 +565,10 @@ impl AuthorizationManagerStateMachine {
                 .or_insert(ManagedAuthorizationState {
                     initiating_state: AuthorizationInitiatingState::Start,
                     accepting_state: AuthorizationAcceptingState::Start,
+                    #[cfg(any(
+                        feature = "trust-authorization",
+                        feature = "challenge-authorization"
+                    ))]
                     received_complete: false,
                     local_authorization: None,
                 });
