@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -429,7 +429,7 @@ impl ShutdownHandle for RemoteYamlShutdownHandle {
     }
 }
 
-#[cfg(all(test, feature = "rest-api", feature = "rest-api-actix"))]
+#[cfg(all(test, feature = "rest-api-actix-web-1"))]
 mod tests {
     use super::*;
 
