@@ -1,4 +1,4 @@
-// Copyright 2018-2021 Cargill Incorporated
+// Copyright 2018-2022 Cargill Incorporated
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -31,7 +31,7 @@ pub trait ServiceFactory: Send {
         args: HashMap<String, String>,
     ) -> Result<Box<dyn Service>, FactoryCreateError>;
 
-    #[cfg(feature = "rest-api")]
+    #[cfg(feature = "rest-api-actix-web-1")]
     /// Get the [`ServiceEndpoint`] definitions that represent the REST API resources provided by
     /// the services that this factory can create.
     ///
